@@ -6,7 +6,7 @@
 ;;         Jun'ichi Shiono  <jun@fsas.fujitsu.com>
 ;;         Yasutaka SHINDOH <ring-pub@fan.gr.jp>
 ;; Created: 2001/06/28
-;; Revised: 2005/05/13
+;; Revised: 2006/01/23
 ;; Keywords: font-lock emacs-lisp change-log texinfo c java perl html
 ;;           mail news
 
@@ -22,8 +22,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with Develock; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -209,7 +209,7 @@
 
 ;;; Code:
 
-(defconst develock-version "0.26"
+(defconst develock-version "0.27"
   "Version number for this version of Develock.")
 
 (require 'advice)
@@ -352,7 +352,10 @@ Those might violate the manners of mail messages or news articles."
 (defface develock-reachable-mail-address-face
   '((t (:foreground "DarkGreen" :background "LemonChiffon")))
   "Develock face used to highlight reachable E-mail addresses.
-That would be defenseless to spammers.")
+That would be defenseless to spammers."
+  :group 'develock
+  :group 'font-lock-highlighting-faces
+  :group 'font-lock-faces)
 
 (defcustom develock-auto-enable t
   "If non-nil, turn Develock mode on when font-lock is turned on."
@@ -950,12 +953,12 @@ Each element should be triple symbols of the following form:
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
      (0 'develock-whitespace-face-2 append))
-    ;; useing upper case tag
+    ;; using upper case tag
     ((lambda (limit)
        (let (case-fold-search)
 	 (re-search-forward "</?\\([A-Z]+\\)" limit t)))
      (1 'develock-upper-case-tag-face t))
-    ;; useing upper case attribute
+    ;; using upper case attribute
     ((lambda (limit)
        (let (case-fold-search)
 	 (re-search-forward "<[a-zA-Z]+[\t ]+\\([A-Z]+\\)[\t ]*=" limit t)))
@@ -1169,6 +1172,16 @@ Energize font-lock keywords for extraordinary level highlighting."
     (let ((develock-inhibit-advice-font-lock-set-defaults t))
       ad-do-it))
   (defadvice font-lock-remove-keywords (around inhibit-develock activate)
+    "Run `font-lock-set-defaults' being not advised by Develock."
+    (let ((develock-inhibit-advice-font-lock-set-defaults t))
+      ad-do-it))
+
+  ;; Those functions call `font-lock-set-defaults' in Emacs 22.
+  (defadvice font-lock-fontify-buffer (around inhibit-develock activate)
+    "Run `font-lock-set-defaults' being not advised by Develock."
+    (let ((develock-inhibit-advice-font-lock-set-defaults t))
+      ad-do-it))
+  (defadvice font-lock-fontify-region (around inhibit-develock activate)
     "Run `font-lock-set-defaults' being not advised by Develock."
     (let ((develock-inhibit-advice-font-lock-set-defaults t))
       ad-do-it)))
